@@ -1,24 +1,9 @@
 import {runInAction} from 'mobx'
-import {AaaSession, localStorageAuthorizationKeyname, AaaAuthorizationSession} from "../types/aaa";
+import {AaaSession, localStorageAuthorizationKeyname, AaaAuthorizationSession, ClientSessionResponse} from "./types";
 import {aaaProvider} from "./provider";
-import {ClientSessionResponse, session} from './session'
-import {request, updateAuthorizationHeader} from 'system/requests'
-
-
-export type AaaInterface = {
-  initializeFromServer(): Promise<any>
-  initializeFromStruct(authsession: ClientSessionResponse): void
-  dropSession(): void
-  getAuthorizationSession(): AaaSession
-  storeAuthorizationSession(session: AaaSession): void
-  dropAuthorizationSession(): void
-  getAuthorizationToken(): string | null
-  getRefreshToken(): string | null
-  authenticate(username: string, password: string): Promise<AaaSession>
-  logout(): void
-  isLoggedIn(): boolean
-  check(): Promise<any>
-}
+import {session} from './session'
+import {updateAuthorizationHeader} from 'system/requests'
+import {AaaInterface} from './types'
 
 
 export const aaa: AaaInterface = {
